==> thrio-0.4.2.tar.gz: lib/src/module/module_route_transitions_builder.dart <==
// The MIT License (MIT)
//
// Copyright (c) 2019 Hellobike Group
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.

import 'package:flutter/foundation.dart';
import 'package:flutter/widgets.dart';
import '../navigator/thrio_navigator_implement.dart';

import 'thrio_module.dart';

mixin ModuleRouteTransitionsBuilder on ThrioModule {
  /// A function for register a `RouteTransitionsBuilder` .
  ///
  void onRouteTransitionsBuilderRegister() {}

  /// Register the `transitionsBuilder` that matches the `urlPattern`.
  ///
  /// Unregistry by calling the return value `VoidCallback`.
  ///
  /// Do not override this method.
  ///
  VoidCallback registerRouteTransitionsBuilder(
    String urlPattern,
    RouteTransitionsBuilder transitionsBuilder,
  ) =>
      ThrioNavigatorImplement.routeTransitionsBuilders
          .registry(RegExp(urlPattern), transitionsBuilder);
}

==> thrio-1.7.5.tar.gz: lib/src/module/module_route_transitions_builder.dart <==
// The MIT License (MIT)
//
// Copyright (c) 2019 Hellobike Group
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.

import 'package:flutter/foundation.dart';
import 'package:flutter/widgets.dart';

import 'thrio_module.dart';

mixin ModuleRouteTransitionsBuilder on ThrioModule {
  RouteTransitionsBuilder _routeTransitionsBuilder;
  @protected
  RouteTransitionsBuilder get routeTransitionsBuilder =>
      _routeTransitionsBuilder;

  set routeTransitionsBuilder(RouteTransitionsBuilder value) {
    if (value == null) {
      routeTransitionsDisabled = true;
    }
    _routeTransitionsBuilder = value;
  }

  @protected
  bool routeTransitionsDisabled = false;

  /// A function for setting a `RouteTransitionsBuilder` .
  ///
  @protected
  void onRouteTransitionsBuilderSetting(ModuleContext moduleContext) {}
}
